@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">

Universitas Pandanaran berdiri sejak tahun 1996 di Semarang. Universitas Ki Ageng Pandanaran Semarang (UNPAND) berdiri tepatnya tanggal 8 Agustus 1996 dengan SK Mendikbud Nomor 59/D/O/1996. UNPAND didirikan atas usaha tokoh pendirinya Bp. Sutrisno Suharto (Walikota Semarang 1990-2000). <br>
Kelangsungan penyelenggaraan Universitas Pandanaran Semarang tidak lepas dari keberadaan Yayasan Abdi Masyarakat. Kota Semarang dan hingga kini masih di kelola oleh Yayasan tersebut. Universitas Pandanaran Semarang memiliki 3 (Tiga) Fakultas dengan 12 (sepuluh) Jurusan/Program Studi meliputi Program Studi Strata Satu (S1) yang terdiri dari Program Studi Teknik Arsitektur, Kewirausahaan, Teknik Sipil, Manajemen dan Akuntansi serta Program Diploma III (D III) meliputi Program Studi Teknik Elektro, Teknik Lingkungan, Teknik Mesin, Teknik Kimia, Teknik Sipil, Hubungan Masyarakat dan Ilmu Administrasi Bisnis. 

                
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
